@@ -4,8 +4,8 @@ __description__ = (
     "Archive pages and retrieve archived pages easily."
 )
 __url__ = "https://akamhy.github.io/waybackpy/"
-__version__ = "3.0.0"
-__author__ = "akamhy"
+__version__ = "3.0.1"
+__author__ = "Akash Mahanty"
 __author_email__ = "akamhy@yahoo.com"
 __license__ = "MIT"
 __copyright__ = "Copyright 2020-2022 Akash Mahanty et al."
